You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ignite.apache.org by se...@apache.org on 2015/02/02 22:57:04 UTC

[21/50] [abbrv] incubator-ignite git commit: gg*{sh, bat} renamed to ignite*{sh, bat}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/java/org/apache/ignite/examples/compute/montecarlo/CreditRiskExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/compute/montecarlo/CreditRiskExample.java b/examples/src/main/java/org/apache/ignite/examples/compute/montecarlo/CreditRiskExample.java
index ce36999..49a2667 100644
--- a/examples/src/main/java/org/apache/ignite/examples/compute/montecarlo/CreditRiskExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/compute/montecarlo/CreditRiskExample.java
@@ -27,7 +27,7 @@ import java.util.*;
  * Monte-Carlo example. Demonstrates distributed credit risk calculation.
  * <p>
  * Remote nodes should always be started with special configuration file which
- * enables P2P class loading: {@code 'ggstart.{sh|bat} examples/config/example-compute.xml'}.
+ * enables P2P class loading: {@code 'ignite.{sh|bat} examples/config/example-compute.xml'}.
  * <p>
  * Alternatively you can run {@link ComputeNodeStartup} in another JVM which will start GridGain node
  * with {@code examples/config/example-compute.xml} configuration.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheAffinityExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheAffinityExample.java b/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheAffinityExample.java
index a0be78e..8d6b275 100644
--- a/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheAffinityExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheAffinityExample.java
@@ -30,7 +30,7 @@ import java.util.*;
  * example is to provide the simplest code example of this logic.
  * <p>
  * Remote nodes should always be started with special configuration file which
- * enables P2P class loading: {@code 'ggstart.{sh|bat} examples/config/example-cache.xml'}.
+ * enables P2P class loading: {@code 'ignite.{sh|bat} examples/config/example-cache.xml'}.
  * <p>
  * Alternatively you can run {@link CacheNodeStartup} in another JVM which will
  * start GridGain node with {@code examples/config/example-cache.xml} configuration.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheApiExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheApiExample.java b/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheApiExample.java
index 218d734..26057c5 100644
--- a/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheApiExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheApiExample.java
@@ -28,7 +28,7 @@ import java.util.concurrent.*;
  * This example demonstrates some of the cache rich API capabilities.
  * <p>
  * Remote nodes should always be started with special configuration file which
- * enables P2P class loading: {@code 'ggstart.{sh|bat} examples/config/example-cache.xml'}.
+ * enables P2P class loading: {@code 'ignite.{sh|bat} examples/config/example-cache.xml'}.
  * <p>
  * Alternatively you can run {@link CacheNodeStartup} in another JVM which will
  * start GridGain node with {@code examples/config/example-cache.xml} configuration.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheContinuousQueryExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheContinuousQueryExample.java b/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheContinuousQueryExample.java
index 2084921..d801148 100644
--- a/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheContinuousQueryExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheContinuousQueryExample.java
@@ -28,7 +28,7 @@ import java.util.*;
  * This examples demonstrates continuous query API.
  * <p>
  * Remote nodes should always be started with special configuration file which
- * enables P2P class loading: {@code 'ggstart.{sh|bat} examples/config/example-cache.xml'}.
+ * enables P2P class loading: {@code 'ignite.{sh|bat} examples/config/example-cache.xml'}.
  * <p>
  * Alternatively you can run {@link CacheNodeStartup} in another JVM which will
  * start GridGain node with {@code examples/config/example-cache.xml} configuration.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheDataLoaderExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheDataLoaderExample.java b/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheDataLoaderExample.java
index 853a72d..b13b625 100644
--- a/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheDataLoaderExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheDataLoaderExample.java
@@ -27,7 +27,7 @@ import org.apache.ignite.examples.*;
  * together and properly manages load on remote nodes.
  * <p>
  * Remote nodes should always be started with special configuration file which
- * enables P2P class loading: {@code 'ggstart.{sh|bat} examples/config/example-cache.xml'}.
+ * enables P2P class loading: {@code 'ignite.{sh|bat} examples/config/example-cache.xml'}.
  * <p>
  * Alternatively you can run {@link CacheNodeStartup} in another JVM which will
  * start GridGain node with {@code examples/config/example-cache.xml} configuration.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheEventsExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheEventsExample.java b/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheEventsExample.java
index bc2c01e..80b4217 100644
--- a/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheEventsExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheEventsExample.java
@@ -31,7 +31,7 @@ import static org.apache.ignite.events.IgniteEventType.*;
  * must be specifically enabled, just like in {@code examples/config/example-cache.xml} file.
  * <p>
  * Remote nodes should always be started with special configuration file which
- * enables P2P class loading: {@code 'ggstart.{sh|bat} examples/config/example-cache.xml'}.
+ * enables P2P class loading: {@code 'ignite.{sh|bat} examples/config/example-cache.xml'}.
  * <p>
  * Alternatively you can run {@link CacheNodeStartup} in another JVM which will
  * start GridGain node with {@code examples/config/example-cache.xml} configuration.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/java/org/apache/ignite/examples/datagrid/CachePopularNumbersExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/datagrid/CachePopularNumbersExample.java b/examples/src/main/java/org/apache/ignite/examples/datagrid/CachePopularNumbersExample.java
index ac73134..1617662 100644
--- a/examples/src/main/java/org/apache/ignite/examples/datagrid/CachePopularNumbersExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/datagrid/CachePopularNumbersExample.java
@@ -30,7 +30,7 @@ import java.util.*;
  * Real time popular numbers counter.
  * <p>
  * Remote nodes should always be started with special configuration file which
- * enables P2P class loading: {@code 'ggstart.{sh|bat} examples/config/example-cache.xml'}.
+ * enables P2P class loading: {@code 'ignite.{sh|bat} examples/config/example-cache.xml'}.
  * <p>
  * Alternatively you can run {@link CacheNodeStartup} in another JVM which will
  * start GridGain node with {@code examples/config/example-cache.xml} configuration.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/java/org/apache/ignite/examples/datagrid/CachePutGetExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/datagrid/CachePutGetExample.java b/examples/src/main/java/org/apache/ignite/examples/datagrid/CachePutGetExample.java
index a6b8f6c..9df8fe5 100644
--- a/examples/src/main/java/org/apache/ignite/examples/datagrid/CachePutGetExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/datagrid/CachePutGetExample.java
@@ -26,7 +26,7 @@ import java.util.*;
  * This example demonstrates very basic operations on cache, such as 'put' and 'get'.
  * <p>
  * Remote nodes should always be started with special configuration file which
- * enables P2P class loading: {@code 'ggstart.{sh|bat} examples/config/example-cache.xml'}.
+ * enables P2P class loading: {@code 'ignite.{sh|bat} examples/config/example-cache.xml'}.
  * <p>
  * Alternatively you can run {@link CacheNodeStartup} in another JVM which will
  * start GridGain node with {@code examples/config/example-cache.xml} configuration.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheQueryExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheQueryExample.java b/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheQueryExample.java
index f7ade22..a0205d6 100644
--- a/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheQueryExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheQueryExample.java
@@ -59,7 +59,7 @@ import java.util.*;
  * </ul>
  * <p>
  * Remote nodes should always be started with special configuration file which
- * enables P2P class loading: {@code 'ggstart.{sh|bat} examples/config/example-cache.xml'}.
+ * enables P2P class loading: {@code 'ignite.{sh|bat} examples/config/example-cache.xml'}.
  * <p>
  * Alternatively you can run {@link CacheNodeStartup} in another JVM which will
  * start GridGain node with {@code examples/config/example-cache.xml} configuration.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheTransactionExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheTransactionExample.java b/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheTransactionExample.java
index db61b22..1e1793f 100644
--- a/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheTransactionExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheTransactionExample.java
@@ -31,7 +31,7 @@ import static org.apache.ignite.transactions.IgniteTxIsolation.*;
  * Demonstrates how to use cache transactions.
  * <p>
  * Remote nodes should always be started with special configuration file which
- * enables P2P class loading: {@code 'ggstart.{sh|bat} examples/config/example-cache.xml'}.
+ * enables P2P class loading: {@code 'ignite.{sh|bat} examples/config/example-cache.xml'}.
  * <p>
  * Alternatively you can run {@link CacheNodeStartup} in another JVM which will
  * start GridGain node with {@code examples/config/example-cache.xml} configuration.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheAtomicLongExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheAtomicLongExample.java b/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheAtomicLongExample.java
index 3e7996e..51359fd 100644
--- a/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheAtomicLongExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheAtomicLongExample.java
@@ -28,7 +28,7 @@ import java.util.*;
  * Demonstrates a simple usage of distributed atomic long.
  * <p>
  * Remote nodes should always be started with special configuration file which
- * enables P2P class loading: {@code 'ggstart.{sh|bat} examples/config/example-cache.xml'}.
+ * enables P2P class loading: {@code 'ignite.{sh|bat} examples/config/example-cache.xml'}.
  * <p>
  * Alternatively you can run {@link CacheNodeStartup} in another JVM which will
  * start GridGain node with {@code examples/config/example-cache.xml} configuration.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheAtomicReferenceExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheAtomicReferenceExample.java b/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheAtomicReferenceExample.java
index eae31f3..fa86d21 100644
--- a/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheAtomicReferenceExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheAtomicReferenceExample.java
@@ -28,7 +28,7 @@ import java.util.*;
  * Demonstrates a simple usage of distributed atomic reference.
  * <p>
  * Remote nodes should always be started with special configuration file which
- * enables P2P class loading: {@code 'ggstart.{sh|bat} examples/config/example-cache.xml'}.
+ * enables P2P class loading: {@code 'ignite.{sh|bat} examples/config/example-cache.xml'}.
  * <p>
  * Alternatively you can run {@link CacheNodeStartup} in another JVM which will
  * start GridGain node with {@code examples/config/example-cache.xml} configuration.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheAtomicSequenceExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheAtomicSequenceExample.java b/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheAtomicSequenceExample.java
index d4ad2ce..1e509ba 100644
--- a/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheAtomicSequenceExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheAtomicSequenceExample.java
@@ -28,7 +28,7 @@ import java.util.*;
  * Demonstrates a simple usage of distributed atomic sequence.
  * <p>
  * Remote nodes should always be started with special configuration file which
- * enables P2P class loading: {@code 'ggstart.{sh|bat} examples/config/example-cache.xml'}.
+ * enables P2P class loading: {@code 'ignite.{sh|bat} examples/config/example-cache.xml'}.
  * <p>
  * Alternatively you can run {@link CacheNodeStartup} in another JVM which will
  * start GridGain node with {@code examples/config/example-cache.xml} configuration.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheAtomicStampedExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheAtomicStampedExample.java b/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheAtomicStampedExample.java
index eb70edd..696c2fe 100644
--- a/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheAtomicStampedExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheAtomicStampedExample.java
@@ -28,7 +28,7 @@ import java.util.*;
  * Demonstrates a simple usage of distributed atomic stamped.
  * <p>
  * Remote nodes should always be started with special configuration file which
- * enables P2P class loading: {@code 'ggstart.{sh|bat} examples/config/example-cache.xml'}.
+ * enables P2P class loading: {@code 'ignite.{sh|bat} examples/config/example-cache.xml'}.
  * <p>
  * Alternatively you can run {@link CacheNodeStartup} in another JVM which will
  * start GridGain node with {@code examples/config/example-cache.xml} configuration.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheCountDownLatchExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheCountDownLatchExample.java b/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheCountDownLatchExample.java
index 495d8ac..bd3c68b 100644
--- a/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheCountDownLatchExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheCountDownLatchExample.java
@@ -28,7 +28,7 @@ import java.util.*;
  * Demonstrates a simple usage of distributed count down latch.
  * <p>
  * Remote nodes should always be started with special configuration file which
- * enables P2P class loading: {@code 'ggstart.{sh|bat} examples/config/example-cache.xml'}.
+ * enables P2P class loading: {@code 'ignite.{sh|bat} examples/config/example-cache.xml'}.
  * <p>
  * Alternatively you can run {@link CacheNodeStartup} in another JVM which will
  * start GridGain node with {@code examples/config/example-cache.xml} configuration.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheQueueExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheQueueExample.java b/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheQueueExample.java
index 5ab64c6..ae1f3b9 100644
--- a/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheQueueExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheQueueExample.java
@@ -29,7 +29,7 @@ import java.util.*;
  * cache queue.
  * <p>
  * Remote nodes should always be started with special configuration file which
- * enables P2P class loading: {@code 'ggstart.{sh|bat} examples/config/example-cache.xml'}.
+ * enables P2P class loading: {@code 'ignite.{sh|bat} examples/config/example-cache.xml'}.
  * <p>
  * Alternatively you can run {@link CacheNodeStartup} in another JVM which will
  * start GridGain node with {@code examples/config/example-cache.xml} configuration.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheSetExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheSetExample.java b/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheSetExample.java
index cff0046..dc68b1e 100644
--- a/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheSetExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheSetExample.java
@@ -28,7 +28,7 @@ import java.util.*;
  * Grid cache distributed set example.
  * <p>
  * Remote nodes should always be started with special configuration file which
- * enables P2P class loading: {@code 'ggstart.{sh|bat} examples/config/example-cache.xml'}.
+ * enables P2P class loading: {@code 'ignite.{sh|bat} examples/config/example-cache.xml'}.
  * <p>
  * Alternatively you can run {@link CacheNodeStartup} in another JVM which will
  * start GridGain node with {@code examples/config/example-cache.xml} configuration.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/java/org/apache/ignite/examples/datagrid/starschema/CacheStarSchemaExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/datagrid/starschema/CacheStarSchemaExample.java b/examples/src/main/java/org/apache/ignite/examples/datagrid/starschema/CacheStarSchemaExample.java
index 65bd6c3..e5a79d4 100644
--- a/examples/src/main/java/org/apache/ignite/examples/datagrid/starschema/CacheStarSchemaExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/datagrid/starschema/CacheStarSchemaExample.java
@@ -42,7 +42,7 @@ import java.util.concurrent.*;
  * in various ways.
  * <p>
  * Remote nodes should always be started with special configuration file which
- * enables P2P class loading: {@code 'ggstart.{sh|bat} examples/config/example-cache.xml'}.
+ * enables P2P class loading: {@code 'ignite.{sh|bat} examples/config/example-cache.xml'}.
  * <p>
  * Alternatively you can run {@link CacheNodeStartup} in another JVM which will
  * start GridGain node with {@code examples/config/example-cache.xml} configuration.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/java/org/apache/ignite/examples/events/EventsExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/events/EventsExample.java b/examples/src/main/java/org/apache/ignite/examples/events/EventsExample.java
index 6877935..fb30474 100644
--- a/examples/src/main/java/org/apache/ignite/examples/events/EventsExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/events/EventsExample.java
@@ -33,7 +33,7 @@ import static org.apache.ignite.events.IgniteEventType.*;
  * Note that grid events are disabled by default and must be specifically enabled,
  * just like in {@code examples/config/example-compute.xml} file.
  * <p>
- * Remote nodes should always be started with configuration: {@code 'ggstart.sh examples/config/example-compute.xml'}.
+ * Remote nodes should always be started with configuration: {@code 'ignite.sh examples/config/example-compute.xml'}.
  * <p>
  * Alternatively you can run {@link ComputeNodeStartup} in another JVM which will start
  * GridGain node with {@code examples/config/example-compute.xml} configuration.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/java/org/apache/ignite/examples/ggfs/GgfsExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/ggfs/GgfsExample.java b/examples/src/main/java/org/apache/ignite/examples/ggfs/GgfsExample.java
index 496541c..b8fa35e 100644
--- a/examples/src/main/java/org/apache/ignite/examples/ggfs/GgfsExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/ggfs/GgfsExample.java
@@ -30,7 +30,7 @@ import java.util.*;
  * files, create, list and delete directories).
  * <p>
  * Remote nodes should always be started with configuration file which includes
- * GGFS: {@code 'ggstart.sh examples/config/filesystem/example-ggfs.xml'}.
+ * GGFS: {@code 'ignite.sh examples/config/filesystem/example-ggfs.xml'}.
  * <p>
  * Alternatively you can run {@link GgfsNodeStartup} in another JVM which will start
  * GridGain node with {@code examples/config/filesystem/example-ggfs.xml} configuration.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/java/org/apache/ignite/examples/ggfs/GgfsMapReduceExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/ggfs/GgfsMapReduceExample.java b/examples/src/main/java/org/apache/ignite/examples/ggfs/GgfsMapReduceExample.java
index 1ba193f..3813e2d 100644
--- a/examples/src/main/java/org/apache/ignite/examples/ggfs/GgfsMapReduceExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/ggfs/GgfsMapReduceExample.java
@@ -31,7 +31,7 @@ import java.util.*;
  * the same way as {@code grep} command does.
  * <p>
  * Remote nodes should always be started with configuration file which includes
- * GGFS: {@code 'ggstart.sh examples/config/filesystem/example-ggfs.xml'}.
+ * GGFS: {@code 'ignite.sh examples/config/filesystem/example-ggfs.xml'}.
  * <p>
  * Alternatively you can run {@link GgfsNodeStartup} in another JVM which will start
  * GridGain node with {@code examples/config/filesystem/example-ggfs.xml} configuration.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/java/org/apache/ignite/examples/ggfs/GgfsNodeStartup.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/ggfs/GgfsNodeStartup.java b/examples/src/main/java/org/apache/ignite/examples/ggfs/GgfsNodeStartup.java
index 381de6b..e2cfea6 100644
--- a/examples/src/main/java/org/apache/ignite/examples/ggfs/GgfsNodeStartup.java
+++ b/examples/src/main/java/org/apache/ignite/examples/ggfs/GgfsNodeStartup.java
@@ -22,8 +22,8 @@ import org.apache.ignite.*;
 /**
  * Starts up an empty node with GGFS configuration.
  * You can also start a stand-alone GridGain instance by passing the path
- * to configuration file to {@code 'ggstart.{sh|bat}'} script, like so:
- * {@code 'ggstart.sh examples/config/filesystem/example-ggfs.xml'}.
+ * to configuration file to {@code 'ignite.{sh|bat}'} script, like so:
+ * {@code 'ignite.sh examples/config/filesystem/example-ggfs.xml'}.
  * <p>
  * The difference is that running this class from IDE adds all example classes to classpath
  * but running from command line doesn't.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/java/org/apache/ignite/examples/messaging/MessagingExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/messaging/MessagingExample.java b/examples/src/main/java/org/apache/ignite/examples/messaging/MessagingExample.java
index 8aabf4e..2629a64 100644
--- a/examples/src/main/java/org/apache/ignite/examples/messaging/MessagingExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/messaging/MessagingExample.java
@@ -34,7 +34,7 @@ import java.util.concurrent.*;
  * To run this example you must have at least one remote node started.
  * <p>
  * Remote nodes should always be started with special configuration file which
- * enables P2P class loading: {@code 'ggstart.{sh|bat} examples/config/example-compute.xml'}.
+ * enables P2P class loading: {@code 'ignite.{sh|bat} examples/config/example-compute.xml'}.
  * <p>
  * Alternatively you can run {@link ComputeNodeStartup} in another JVM which will start GridGain node
  * with {@code examples/config/example-compute.xml} configuration.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/java/org/apache/ignite/examples/messaging/MessagingPingPongExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/messaging/MessagingPingPongExample.java b/examples/src/main/java/org/apache/ignite/examples/messaging/MessagingPingPongExample.java
index 11edc44..a22b2aa 100644
--- a/examples/src/main/java/org/apache/ignite/examples/messaging/MessagingPingPongExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/messaging/MessagingPingPongExample.java
@@ -33,7 +33,7 @@ import java.util.concurrent.*;
  * To run this example you must have at least one remote node started.
  * <p>
  * Remote nodes should always be started with special configuration file which
- * enables P2P class loading: {@code 'ggstart.{sh|bat} examples/config/example-compute.xml'}.
+ * enables P2P class loading: {@code 'ignite.{sh|bat} examples/config/example-compute.xml'}.
  * <p>
  * Alternatively you can run {@link ComputeNodeStartup} in another JVM which will start GridGain node
  * with {@code examples/config/example-compute.xml} configuration.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/java/org/apache/ignite/examples/messaging/MessagingPingPongListenActorExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/messaging/MessagingPingPongListenActorExample.java b/examples/src/main/java/org/apache/ignite/examples/messaging/MessagingPingPongListenActorExample.java
index 65fa6ae..eec94a7 100644
--- a/examples/src/main/java/org/apache/ignite/examples/messaging/MessagingPingPongListenActorExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/messaging/MessagingPingPongListenActorExample.java
@@ -31,7 +31,7 @@ import java.util.concurrent.*;
  * To run this example you must have at least one remote node started.
  * <p>
  * Remote nodes should always be started with special configuration file which
- * enables P2P class loading: {@code 'ggstart.{sh|bat} examples/config/example-compute.xml'}.
+ * enables P2P class loading: {@code 'ignite.{sh|bat} examples/config/example-compute.xml'}.
  * <p>
  * Alternatively you can run {@link ComputeNodeStartup} in another JVM which will start GridGain node
  * with {@code examples/config/example-compute.xml} configuration.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/java/org/apache/ignite/examples/misc/deployment/DeploymentExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/misc/deployment/DeploymentExample.java b/examples/src/main/java/org/apache/ignite/examples/misc/deployment/DeploymentExample.java
index 873a63f..64151f6 100644
--- a/examples/src/main/java/org/apache/ignite/examples/misc/deployment/DeploymentExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/misc/deployment/DeploymentExample.java
@@ -40,7 +40,7 @@ import java.util.*;
  * in system classpath, so even in this case the deployment step is unnecessary.
  * <p>
  * Remote nodes should always be started with special configuration file which
- * enables P2P class loading: {@code 'ggstart.{sh|bat} examples/config/example-cache.xml'}.
+ * enables P2P class loading: {@code 'ignite.{sh|bat} examples/config/example-cache.xml'}.
  * <p>
  * Alternatively you can run {@link ComputeNodeStartup} in another JVM which will
  * start GridGain node with {@code examples/config/example-compute.xml} configuration.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/java/org/apache/ignite/examples/misc/springbean/SpringBeanExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/misc/springbean/SpringBeanExample.java b/examples/src/main/java/org/apache/ignite/examples/misc/springbean/SpringBeanExample.java
index 83a3e17..709fb2b 100644
--- a/examples/src/main/java/org/apache/ignite/examples/misc/springbean/SpringBeanExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/misc/springbean/SpringBeanExample.java
@@ -36,7 +36,7 @@ import java.util.concurrent.*;
  * apply grid bean destructor and stop the grid.
  * <p>
  * Remote nodes should always be started with special configuration file which
- * enables P2P class loading: {@code 'ggstart.{sh|bat} examples/config/example-compute.xml'}.
+ * enables P2P class loading: {@code 'ignite.{sh|bat} examples/config/example-compute.xml'}.
  * <p>
  * Alternatively you can run {@link ComputeNodeStartup} in another JVM which will start GridGain node
  * with {@code examples/config/example-compute.xml} configuration.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/java/org/apache/ignite/examples/services/ServicesExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/services/ServicesExample.java b/examples/src/main/java/org/apache/ignite/examples/services/ServicesExample.java
index c5d0c51..7481137 100644
--- a/examples/src/main/java/org/apache/ignite/examples/services/ServicesExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/services/ServicesExample.java
@@ -34,7 +34,7 @@ import java.util.*;
  * which will start GridGain node with {@code examples/config/example-compute.xml} configuration.
  * <p>
  * NOTE:<br/>
- * Starting {@code ggstart.sh} directly will not work, as distributed services
+ * Starting {@code ignite.sh} directly will not work, as distributed services
  * cannot be peer-deployed and classes must be on the classpath for every node.
  */
 public class ServicesExample {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/java/org/apache/ignite/examples/streaming/StreamingCheckInExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/streaming/StreamingCheckInExample.java b/examples/src/main/java/org/apache/ignite/examples/streaming/StreamingCheckInExample.java
index 2b3c0e8..6423d1e 100644
--- a/examples/src/main/java/org/apache/ignite/examples/streaming/StreamingCheckInExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/streaming/StreamingCheckInExample.java
@@ -52,7 +52,7 @@ import java.util.concurrent.*;
  * the users that have checked-in in the known places within the last 10 seconds.
  * <p>
  * Remote nodes should always be started with special configuration file:
- * {@code 'ggstart.{sh|bat} examples/config/example-streamer.xml'}.
+ * {@code 'ignite.{sh|bat} examples/config/example-streamer.xml'}.
  * When starting nodes this way JAR file containing the examples code
  * should be placed to {@code IGNITE_HOME/libs} folder. You can build
  * {@code gridgain-examples.jar} by running {@code mvn package} in

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/java/org/apache/ignite/examples/streaming/StreamingPopularNumbersExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/streaming/StreamingPopularNumbersExample.java b/examples/src/main/java/org/apache/ignite/examples/streaming/StreamingPopularNumbersExample.java
index 56712bf..81e91f9 100644
--- a/examples/src/main/java/org/apache/ignite/examples/streaming/StreamingPopularNumbersExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/streaming/StreamingPopularNumbersExample.java
@@ -35,7 +35,7 @@ import java.util.*;
  * is set to {@code 10,000}.
  * <p>
  * Remote nodes should always be started with special configuration file:
- * {@code 'ggstart.{sh|bat} examples/config/example-streamer.xml'}.
+ * {@code 'ignite.{sh|bat} examples/config/example-streamer.xml'}.
  * When starting nodes this way JAR file containing the examples code
  * should be placed to {@code IGNITE_HOME/libs} folder. You can build
  * {@code gridgain-examples.jar} by running {@code mvn package} in

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/java/org/apache/ignite/examples/streaming/StreamingPriceBarsExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/streaming/StreamingPriceBarsExample.java b/examples/src/main/java/org/apache/ignite/examples/streaming/StreamingPriceBarsExample.java
index 708564e..584e55a 100644
--- a/examples/src/main/java/org/apache/ignite/examples/streaming/StreamingPriceBarsExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/streaming/StreamingPriceBarsExample.java
@@ -46,7 +46,7 @@ import java.util.concurrent.*;
  * with purpose to demonstrate multi-stage streaming processing.
  * <p>
  * Remote nodes should always be started with special configuration file:
- * {@code 'ggstart.{sh|bat} examples/config/example-streamer.xml'}.
+ * {@code 'ignite.{sh|bat} examples/config/example-streamer.xml'}.
  * When starting nodes this way JAR file containing the examples code
  * should be placed to {@code IGNITE_HOME/libs} folder. You can build
  * {@code gridgain-examples.jar} by running {@code mvn package} in

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/java/org/apache/ignite/examples/streaming/StreamingRunningAverageExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/streaming/StreamingRunningAverageExample.java b/examples/src/main/java/org/apache/ignite/examples/streaming/StreamingRunningAverageExample.java
index 3b6f52e..7ccbf42 100644
--- a/examples/src/main/java/org/apache/ignite/examples/streaming/StreamingRunningAverageExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/streaming/StreamingRunningAverageExample.java
@@ -32,7 +32,7 @@ import java.util.concurrent.*;
  * continuously maintains a running average over last {@code 500} numbers.
  * <p>
  * Remote nodes should always be started with special configuration file:
- * {@code 'ggstart.{sh|bat} examples/config/example-streamer.xml'}.
+ * {@code 'ignite.{sh|bat} examples/config/example-streamer.xml'}.
  * When starting nodes this way JAR file containing the examples code
  * should be placed to {@code IGNITE_HOME/libs} folder. You can build
  * {@code gridgain-examples.jar} by running {@code mvn package} in

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/java8/org/apache/ignite/examples/ComputeExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java8/org/apache/ignite/examples/ComputeExample.java b/examples/src/main/java8/org/apache/ignite/examples/ComputeExample.java
index 6bcb12c..71b9946 100644
--- a/examples/src/main/java8/org/apache/ignite/examples/ComputeExample.java
+++ b/examples/src/main/java8/org/apache/ignite/examples/ComputeExample.java
@@ -26,7 +26,7 @@ import org.apache.ignite.lang.IgniteCallable;
  * Demonstrates broadcasting and unicasting computations within grid projection.
  * <p>
  * Remote nodes should always be started with special configuration file which
- * enables P2P class loading: {@code 'ggstart.{sh|bat} examples/config/example-compute.xml'}.
+ * enables P2P class loading: {@code 'ignite.{sh|bat} examples/config/example-compute.xml'}.
  */
 public class ComputeExample {
     /**

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/java8/org/apache/ignite/examples/MessagingExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java8/org/apache/ignite/examples/MessagingExample.java b/examples/src/main/java8/org/apache/ignite/examples/MessagingExample.java
index dd7e1ea..c69c3ab 100644
--- a/examples/src/main/java8/org/apache/ignite/examples/MessagingExample.java
+++ b/examples/src/main/java8/org/apache/ignite/examples/MessagingExample.java
@@ -31,7 +31,7 @@ import java.util.concurrent.*;
  * To run this example you must have at least one remote node started.
  * <p>
  * Remote nodes should always be started with special configuration file which
- * enables P2P class loading: {@code 'ggstart.{sh|bat} examples/config/example-compute.xml'}.
+ * enables P2P class loading: {@code 'ignite.{sh|bat} examples/config/example-compute.xml'}.
  * <p>
  * Alternatively you can run {@link ComputeNodeStartup} in another JVM which will start GridGain node
  * with {@code examples/config/example-compute.xml} configuration.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheAffinityExample1.scala
----------------------------------------------------------------------
diff --git a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheAffinityExample1.scala b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheAffinityExample1.scala
index 2598e93..b0ca960 100644
--- a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheAffinityExample1.scala
+++ b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheAffinityExample1.scala
@@ -34,7 +34,7 @@ import java.util.concurrent.Callable
  * keys.
  *
  * Remote nodes should always be started with configuration file which includes
- * cache: `'ggstart.sh examples/config/example-cache.xml'`. Local node can
+ * cache: `'ignite.sh examples/config/example-cache.xml'`. Local node can
  * be started with or without cache.
  */
 object ScalarCacheAffinityExample1 {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheAffinityExample2.scala
----------------------------------------------------------------------
diff --git a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheAffinityExample2.scala b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheAffinityExample2.scala
index bc6f0a1..e12f3bf 100644
--- a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheAffinityExample2.scala
+++ b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheAffinityExample2.scala
@@ -28,7 +28,7 @@ import scala.util.control.Breaks._
  * Note that affinity routing is enabled for all caches.
  *
  * Remote nodes should always be started with configuration file which includes
- * cache: `'ggstart.sh examples/config/example-cache.xml'`. Local node can
+ * cache: `'ignite.sh examples/config/example-cache.xml'`. Local node can
  * be started with or without cache.
  */
 object ScalarCacheAffinityExample2 {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheAffinitySimpleExample.scala
----------------------------------------------------------------------
diff --git a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheAffinitySimpleExample.scala b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheAffinitySimpleExample.scala
index 103bcb3..12c2f96 100644
--- a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheAffinitySimpleExample.scala
+++ b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheAffinitySimpleExample.scala
@@ -32,7 +32,7 @@ import org.apache.ignite.scalar.scalar._
  * Note also that for affinity routing is enabled for all caches.
  *
  * Remote nodes should always be started with configuration file which includes
- * cache: `'ggstart.sh examples/config/example-cache.xml'`. Local node can
+ * cache: `'ignite.sh examples/config/example-cache.xml'`. Local node can
  * be started with or without cache.
  */
 object ScalarCacheAffinitySimpleExample extends App {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheExample.scala
----------------------------------------------------------------------
diff --git a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheExample.scala b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheExample.scala
index 574006f..22ab99e 100644
--- a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheExample.scala
+++ b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheExample.scala
@@ -30,7 +30,7 @@ import scala.collection.JavaConversions._
  * Demonstrates basic In-Memory Data Grid operations with Scalar.
  * <p>
  * Remote nodes should always be started with configuration file which includes
- * cache: `'ggstart.sh examples/config/example-cache.xml'`. Local node can
+ * cache: `'ignite.sh examples/config/example-cache.xml'`. Local node can
  * be started with or without cache.
  */
 object ScalarCacheExample extends App {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCachePopularNumbersExample.scala
----------------------------------------------------------------------
diff --git a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCachePopularNumbersExample.scala b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCachePopularNumbersExample.scala
index 4cf0b04..e52f431 100644
--- a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCachePopularNumbersExample.scala
+++ b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCachePopularNumbersExample.scala
@@ -30,7 +30,7 @@ import scala.util.Random
  * Real time popular number counter.
  * <p>
  * Remote nodes should always be started with special configuration file which
- * enables P2P class loading: `ggstart.sh examples/config/example-cache.xml`
+ * enables P2P class loading: `ignite.sh examples/config/example-cache.xml`
  * <p>
  * Alternatively you can run [[CacheNodeStartup]] in another JVM which will
  * start GridGain node with `examples/config/example-cache.xml` configuration.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheQueryExample.scala
----------------------------------------------------------------------
diff --git a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheQueryExample.scala b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheQueryExample.scala
index 99334f4..d189e9f 100644
--- a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheQueryExample.scala
+++ b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheQueryExample.scala
@@ -31,7 +31,7 @@ import java.util._
  * Demonstrates cache ad-hoc queries with Scalar.
  * <p>
  * Remote nodes should always be started with configuration file which includes
- * cache: `'ggstart.sh examples/config/example-cache.xml'`. Local node can
+ * cache: `'ignite.sh examples/config/example-cache.xml'`. Local node can
  * be started with or without cache.
  */
 object ScalarCacheQueryExample {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarClosureExample.scala
----------------------------------------------------------------------
diff --git a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarClosureExample.scala b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarClosureExample.scala
index 3587356..fc4b46b 100644
--- a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarClosureExample.scala
+++ b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarClosureExample.scala
@@ -25,7 +25,7 @@ import org.apache.ignite.scalar.scalar._
  * Demonstrates various closure executions on the cloud using Scalar.
  * <p>
  * Remote nodes should always be started with special configuration file which
- * enables P2P class loading: `'ggstart.{sh|bat} examples/config/example-compute.xml'`.
+ * enables P2P class loading: `'ignite.{sh|bat} examples/config/example-compute.xml'`.
  */
 object ScalarClosureExample extends App {
     scalar("examples/config/example-compute.xml") {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarContinuationExample.scala
----------------------------------------------------------------------
diff --git a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarContinuationExample.scala b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarContinuationExample.scala
index 7218490..1c1dc46 100644
--- a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarContinuationExample.scala
+++ b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarContinuationExample.scala
@@ -40,7 +40,7 @@ import java.util
  * the more values it will be cached on remote nodes.
  * <p>
  * Remote nodes should always be started with special configuration file which
- * enables P2P class loading: `'ggstart.{sh|bat} examples/config/example-compute.xml'`.
+ * enables P2P class loading: `'ignite.{sh|bat} examples/config/example-compute.xml'`.
  */
 object ScalarContinuationExample {
     def main(args: Array[String]) {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCreditRiskExample.scala
----------------------------------------------------------------------
diff --git a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCreditRiskExample.scala b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCreditRiskExample.scala
index 1affeb9..65393f7 100644
--- a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCreditRiskExample.scala
+++ b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCreditRiskExample.scala
@@ -27,7 +27,7 @@ import scala.util.control.Breaks._
  * Scalar-based Monte-Carlo example.
  * <p>
  * Remote nodes should always be started with special configuration file which
- * enables P2P class loading: `'ggstart.{sh|bat} examples/config/example-compute.xml'`.
+ * enables P2P class loading: `'ignite.{sh|bat} examples/config/example-compute.xml'`.
  */
 object ScalarCreditRiskExample {
     def main(args: Array[String]) {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarPiCalculationExample.scala
----------------------------------------------------------------------
diff --git a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarPiCalculationExample.scala b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarPiCalculationExample.scala
index 3064108..12b72b7 100644
--- a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarPiCalculationExample.scala
+++ b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarPiCalculationExample.scala
@@ -28,7 +28,7 @@ import scala.math._
  * or any explicit deployment.
  * <p>
  * Remote nodes should always be started with special configuration file which
- * enables P2P class loading: `'ggstart.{sh|bat} examples/config/example-compute.xml'`.
+ * enables P2P class loading: `'ignite.{sh|bat} examples/config/example-compute.xml'`.
  */
 object ScalarPiCalculationExample {
     /** Number of iterations per node. */

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarPingPongExample.scala
----------------------------------------------------------------------
diff --git a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarPingPongExample.scala b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarPingPongExample.scala
index bff48a4..dbdd9e0 100644
--- a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarPingPongExample.scala
+++ b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarPingPongExample.scala
@@ -29,7 +29,7 @@ import java.util.concurrent.CountDownLatch
  * two nodes. It is analogous to `GridMessagingPingPongExample` on Java side.
  * <p>
  * Remote nodes should always be started with special configuration file which
- * enables P2P class loading: `'ggstart.{sh|bat} examples/config/example-compute.xml'`.
+ * enables P2P class loading: `'ignite.{sh|bat} examples/config/example-compute.xml'`.
  */
 object ScalarPingPongExample extends App {
     scalar("examples/config/example-compute.xml") {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarPrimeExample.scala
----------------------------------------------------------------------
diff --git a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarPrimeExample.scala b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarPrimeExample.scala
index 1165ef9..3a29101 100644
--- a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarPrimeExample.scala
+++ b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarPrimeExample.scala
@@ -30,7 +30,7 @@ import scala.util.control.Breaks._
  * ==Starting Remote Nodes==
  * To try this example you should (but don't have to) start remote grid instances.
  * You can start as many as you like by executing the following script:
- * `{IGNITE_HOME}/bin/ggstart.{bat|sh} examples/config/example-compute.xml`
+ * `{IGNITE_HOME}/bin/ignite.{bat|sh} examples/config/example-compute.xml`
  *
  * Once remote instances are started, you can execute this example from
  * Eclipse, IntelliJ IDEA, or NetBeans (and any other Java IDE) by simply hitting run

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarScheduleExample.scala
----------------------------------------------------------------------
diff --git a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarScheduleExample.scala b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarScheduleExample.scala
index a5b79ca..299bc0f 100644
--- a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarScheduleExample.scala
+++ b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarScheduleExample.scala
@@ -26,7 +26,7 @@ import org.apache.ignite.scalar.scalar._
  * three times with initial scheduling delay equal to five seconds.
  * <p>
  * Remote nodes should always be started with special configuration file which
- * enables P2P class loading: `'ggstart.{sh|bat} examples/config/example-compute.xml'`.
+ * enables P2P class loading: `'ignite.{sh|bat} examples/config/example-compute.xml'`.
  */
 object ScalarScheduleExample extends App {
     scalar("examples/config/example-compute.xml") {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarSnowflakeSchemaExample.scala
----------------------------------------------------------------------
diff --git a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarSnowflakeSchemaExample.scala b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarSnowflakeSchemaExample.scala
index 574a816..9791d87 100644
--- a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarSnowflakeSchemaExample.scala
+++ b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarSnowflakeSchemaExample.scala
@@ -44,7 +44,7 @@ import scala.collection.JavaConversions._
  * in various ways.
  * <p>
  * Remote nodes should always be started with configuration file which includes
- * cache: `'ggstart.sh examples/config/example-cache.xml'`.
+ * cache: `'ignite.sh examples/config/example-cache.xml'`.
  */
 object ScalarSnowflakeSchemaExample {
     /** Name of replicated cache specified in spring configuration. */

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarTaskExample.scala
----------------------------------------------------------------------
diff --git a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarTaskExample.scala b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarTaskExample.scala
index cd98f06..7dc8c5f 100644
--- a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarTaskExample.scala
+++ b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarTaskExample.scala
@@ -32,7 +32,7 @@ import scala.collection.JavaConversions._
  * As a trade off in such cases the more code needs to be written vs. simple closure execution.
  * <p>
  * Remote nodes should always be started with special configuration file which
- * enables P2P class loading: `'ggstart.{sh|bat} examples/config/example-compute.xml'`.
+ * enables P2P class loading: `'ignite.{sh|bat} examples/config/example-compute.xml'`.
  */
 object ScalarTaskExample extends App {
     scalar("examples/config/example-compute.xml") {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarWorldShortestMapReduce.scala
----------------------------------------------------------------------
diff --git a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarWorldShortestMapReduce.scala b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarWorldShortestMapReduce.scala
index 674c69a..8d73cda 100644
--- a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarWorldShortestMapReduce.scala
+++ b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarWorldShortestMapReduce.scala
@@ -26,7 +26,7 @@ import org.apache.ignite.scalar.scalar._
  * on thousands requiring no special configuration or deployment.
  * <p>
  * Remote nodes should always be started with special configuration file which
- * enables P2P class loading: `'ggstart.{sh|bat} examples/config/example-compute.xml'`.
+ * enables P2P class loading: `'ignite.{sh|bat} examples/config/example-compute.xml'`.
  */
 object ScalarWorldShortestMapReduce extends App {
     scalar("examples/config/example-compute.xml") {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/modules/aop/readme.txt
----------------------------------------------------------------------
diff --git a/modules/aop/readme.txt b/modules/aop/readme.txt
index 75c5f49..4d04630 100644
--- a/modules/aop/readme.txt
+++ b/modules/aop/readme.txt
@@ -5,7 +5,7 @@ Apache Ignite AOP module provides capability to turn any Java method to a distri
 adding @Gridify annotation to it.
 
 To enable AOP module when starting a standalone node, move 'optional/ignite-aop' folder to
-'libs' folder before running 'ggstart.{sh|bat}' script. The content of the module folder will
+'libs' folder before running 'ignite.{sh|bat}' script. The content of the module folder will
 be added to classpath in this case.
 
 Importing AOP Module In Maven Project

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/modules/aws/readme.txt
----------------------------------------------------------------------
diff --git a/modules/aws/readme.txt b/modules/aws/readme.txt
index 317369c..1819915 100644
--- a/modules/aws/readme.txt
+++ b/modules/aws/readme.txt
@@ -4,7 +4,7 @@ Apache Ignite AWS Module
 Apache Ignite AWS module provides S3-based implementations of checkpoint SPI and IP finder for TCP discovery.
 
 To enable AWS module when starting a standalone node, move 'optional/ignite-aws' folder to
-'libs' folder before running 'ggstart.{sh|bat}' script. The content of the module folder will
+'libs' folder before running 'ignite.{sh|bat}' script. The content of the module folder will
 be added to classpath in this case.
 
 Importing AWS Module In Maven Project

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/modules/clients/src/test/bin/start-nodes.cmd
----------------------------------------------------------------------
diff --git a/modules/clients/src/test/bin/start-nodes.cmd b/modules/clients/src/test/bin/start-nodes.cmd
index ece9ee2..5e1fdb2 100644
--- a/modules/clients/src/test/bin/start-nodes.cmd
+++ b/modules/clients/src/test/bin/start-nodes.cmd
@@ -35,9 +35,9 @@ mkdir %IGNITE_HOME%\work\log
 
 set JVM_OPTS=-DCLIENTS_MODULE_PATH=%CLIENTS_MODULE_PATH%
 
-FOR /L %%G IN (1,1,%NODES_COUNT%) DO start "Node #%%G" /low /MIN cmd /C "%BIN_PATH%\ggstart.bat -v %CONFIG_DIR%\spring-server-node.xml >> %IGNITE_HOME%\work\log\node-%%G.log 2>&1"
-FOR /L %%G IN (1,1,%NODES_COUNT%) DO start "SSL Node #%%G" /low /MIN cmd /C "%BIN_PATH%\ggstart.bat -v %CONFIG_DIR%\spring-server-ssl-node.xml >> %IGNITE_HOME%\work\log\node-ssl-%%G.log 2>&1"
-FOR /L %%G IN (1,1,%NODES_COUNT%) DO start "Cache Node #%%G" /low /MIN cmd /C "%BIN_PATH%\ggstart.bat -v %CONFIG_DIR%\spring-cache.xml >> %IGNITE_HOME%\work\log\cache-node-%%G.log 2>&1"
+FOR /L %%G IN (1,1,%NODES_COUNT%) DO start "Node #%%G" /low /MIN cmd /C "%BIN_PATH%\ignite.bat -v %CONFIG_DIR%\spring-server-node.xml >> %IGNITE_HOME%\work\log\node-%%G.log 2>&1"
+FOR /L %%G IN (1,1,%NODES_COUNT%) DO start "SSL Node #%%G" /low /MIN cmd /C "%BIN_PATH%\ignite.bat -v %CONFIG_DIR%\spring-server-ssl-node.xml >> %IGNITE_HOME%\work\log\node-ssl-%%G.log 2>&1"
+FOR /L %%G IN (1,1,%NODES_COUNT%) DO start "Cache Node #%%G" /low /MIN cmd /C "%BIN_PATH%\ignite.bat -v %CONFIG_DIR%\spring-cache.xml >> %IGNITE_HOME%\work\log\cache-node-%%G.log 2>&1"
 
 echo Wait 60 seconds while nodes started.
 ping -n 60 127.0.0.1 > NUL
@@ -45,8 +45,8 @@ ping -n 60 127.0.0.1 > NUL
 rem Disable hostname verification for self-signed certificates.
 set JVM_OPTS=%JVM_OPTS% -DIGNITE_DISABLE_HOSTNAME_VERIFIER=true
 
-FOR /L %%G IN (1,1,1) DO start "Router #%%G" /low /MIN cmd /C "%BIN_PATH%\ggrouter.bat -v %CONFIG_DIR%\spring-router.xml >> %IGNITE_HOME%\work\log\router-%%G.log 2>&1"
-FOR /L %%G IN (1,1,1) DO start "SSL Router #%%G" /low /MIN cmd /C "%BIN_PATH%\ggrouter.bat -v %CONFIG_DIR%\spring-router-ssl.xml >> %IGNITE_HOME%\work\log\router-ssl-%%G.log 2>&1"
+FOR /L %%G IN (1,1,1) DO start "Router #%%G" /low /MIN cmd /C "%BIN_PATH%\igniterouter.bat -v %CONFIG_DIR%\spring-router.xml >> %IGNITE_HOME%\work\log\router-%%G.log 2>&1"
+FOR /L %%G IN (1,1,1) DO start "SSL Router #%%G" /low /MIN cmd /C "%BIN_PATH%\igniterouter.bat -v %CONFIG_DIR%\spring-router-ssl.xml >> %IGNITE_HOME%\work\log\router-ssl-%%G.log 2>&1"
 
 echo Wait 10 seconds while routers started.
 ping -n 10 127.0.0.1 > NUL

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/modules/clients/src/test/bin/start-nodes.sh
----------------------------------------------------------------------
diff --git a/modules/clients/src/test/bin/start-nodes.sh b/modules/clients/src/test/bin/start-nodes.sh
index 739a81e..cb68204 100644
--- a/modules/clients/src/test/bin/start-nodes.sh
+++ b/modules/clients/src/test/bin/start-nodes.sh
@@ -63,7 +63,7 @@ do
     LOG_FILE=${IGNITE_HOME}/work/log/node-${iter}.log
 
     echo Start node ${iter}: ${LOG_FILE}
-    nohup /bin/bash $BIN_PATH/ggstart.sh $CONFIG_DIR/spring-server-node.xml -v < /dev/null > ${LOG_FILE} 2>&1 &
+    nohup /bin/bash $BIN_PATH/ignite.sh $CONFIG_DIR/spring-server-node.xml -v < /dev/null > ${LOG_FILE} 2>&1 &
 done
 
 for iter in {1..2}
@@ -71,7 +71,7 @@ do
     LOG_FILE=${IGNITE_HOME}/work/log/node-ssl-${iter}.log
 
     echo Start SSL node ${iter}: ${LOG_FILE}
-    nohup /bin/bash $BIN_PATH/ggstart.sh $CONFIG_DIR/spring-server-ssl-node.xml -v < /dev/null > ${LOG_FILE} 2>&1 &
+    nohup /bin/bash $BIN_PATH/ignite.sh $CONFIG_DIR/spring-server-ssl-node.xml -v < /dev/null > ${LOG_FILE} 2>&1 &
 done
 
 echo Wait 60 seconds while nodes start.
@@ -79,14 +79,14 @@ sleep 60
 
 LOG_FILE=${IGNITE_HOME}/work/log/router.log
 echo Start Router: ${LOG_FILE}
-nohup /bin/bash $BIN_PATH/ggrouter.sh $CONFIG_DIR/spring-router.xml -v < /dev/null > ${LOG_FILE} 2>&1 &
+nohup /bin/bash $BIN_PATH/igniterouter.sh $CONFIG_DIR/spring-router.xml -v < /dev/null > ${LOG_FILE} 2>&1 &
 
 # Disable hostname verification for self-signed certificates.
 export JVM_OPTS="${JVM_OPTS} -DIGNITE_DISABLE_HOSTNAME_VERIFIER=true"
 
 LOG_FILE=${IGNITE_HOME}/work/log/router-ssl.log
 echo Start Router SSL: ${LOG_FILE}
-nohup /bin/bash $BIN_PATH/ggrouter.sh $CONFIG_DIR/spring-router-ssl.xml -v < /dev/null > ${LOG_FILE} 2>&1 &
+nohup /bin/bash $BIN_PATH/igniterouter.sh $CONFIG_DIR/spring-router-ssl.xml -v < /dev/null > ${LOG_FILE} 2>&1 &
 
 echo Wait 30 seconds while router starts.
 sleep 30

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/modules/clients/src/test/resources/spring-cache.xml
----------------------------------------------------------------------
diff --git a/modules/clients/src/test/resources/spring-cache.xml b/modules/clients/src/test/resources/spring-cache.xml
index b675635..a2e62a9 100644
--- a/modules/clients/src/test/resources/spring-cache.xml
+++ b/modules/clients/src/test/resources/spring-cache.xml
@@ -21,7 +21,7 @@
     GridGain Spring configuration file to startup grid cache.
 
     When starting a standalone GridGain node, you need to execute the following command:
-    {IGNITE_HOME}/bin/ggstart.{bat|sh} examples/config/example-cache.xml
+    {IGNITE_HOME}/bin/ignite.{bat|sh} examples/config/example-cache.xml
 
     When starting GridGain from Java IDE, pass path to this file into GridGain:
     GridGain.start("examples/config/example-cache.xml");

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/modules/clients/src/test/resources/spring-router-ssl.xml
----------------------------------------------------------------------
diff --git a/modules/clients/src/test/resources/spring-router-ssl.xml b/modules/clients/src/test/resources/spring-router-ssl.xml
index e4906c9..bf1a342 100644
--- a/modules/clients/src/test/resources/spring-router-ssl.xml
+++ b/modules/clients/src/test/resources/spring-router-ssl.xml
@@ -21,7 +21,7 @@
     Default rest router configuration.
 
     This file is automatically scanned by
-    $IGNITE_HOME/bin/ggrouter.sh and $IGNITE_HOME/bin/ggrouter.bat
+    $IGNITE_HOME/bin/igniterouter.sh and $IGNITE_HOME/bin/igniterouter.bat
     for org.gridgain.client.router.GridTcpRestRouterConfiguration and
     org.gridgain.client.router.GridHttpRestRouterConfiguration bean definitions.
     First found are used to start corresponding router instances.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/modules/clients/src/test/resources/spring-router.xml
----------------------------------------------------------------------
diff --git a/modules/clients/src/test/resources/spring-router.xml b/modules/clients/src/test/resources/spring-router.xml
index 09e68d8..ba078f5 100644
--- a/modules/clients/src/test/resources/spring-router.xml
+++ b/modules/clients/src/test/resources/spring-router.xml
@@ -21,7 +21,7 @@
     Default rest router configuration.
 
     This file is automatically scanned by
-    $IGNITE_HOME/bin/ggrouter.sh and $IGNITE_HOME/bin/ggrouter.bat
+    $IGNITE_HOME/bin/igniterouter.sh and $IGNITE_HOME/bin/igniterouter.bat
     for org.gridgain.client.router.GridTcpRestRouterConfiguration and
     org.gridgain.client.router.GridHttpRestRouterConfiguration bean definitions.
     First found are used to start corresponding router instances.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/modules/clients/src/test/resources/spring-server-node.xml
----------------------------------------------------------------------
diff --git a/modules/clients/src/test/resources/spring-server-node.xml b/modules/clients/src/test/resources/spring-server-node.xml
index 690fd7d..ccfcf0f 100644
--- a/modules/clients/src/test/resources/spring-server-node.xml
+++ b/modules/clients/src/test/resources/spring-server-node.xml
@@ -21,7 +21,7 @@
     GridGain Spring configuration file to startup grid cache.
 
     When starting a standalone GridGain node, you need to execute the following command:
-    {IGNITE_HOME}/bin/ggstart.{bat|sh} path-to-this-file/example-cache.xml
+    {IGNITE_HOME}/bin/ignite.{bat|sh} path-to-this-file/example-cache.xml
 
     When starting GridGain from Java IDE, pass path to this file into GridGain:
     GridGain.start("path-to-this-file/example-benchmark.xml");

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/modules/clients/src/test/resources/spring-server-ssl-node.xml
----------------------------------------------------------------------
diff --git a/modules/clients/src/test/resources/spring-server-ssl-node.xml b/modules/clients/src/test/resources/spring-server-ssl-node.xml
index e02727d..68774da 100644
--- a/modules/clients/src/test/resources/spring-server-ssl-node.xml
+++ b/modules/clients/src/test/resources/spring-server-ssl-node.xml
@@ -21,7 +21,7 @@
     GridGain Spring configuration file to startup grid cache.
 
     When starting a standalone GridGain node, you need to execute the following command:
-    {IGNITE_HOME}/bin/ggstart.{bat|sh} path-to-this-file/example-cache.xml
+    {IGNITE_HOME}/bin/ignite.{bat|sh} path-to-this-file/example-cache.xml
 
     When starting GridGain from Java IDE, pass path to this file into GridGain:
     GridGain.start("path-to-this-file/example-benchmark.xml");

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/modules/core/src/main/java/org/apache/ignite/IgniteCluster.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/IgniteCluster.java b/modules/core/src/main/java/org/apache/ignite/IgniteCluster.java
index c518ec8..6613fdd 100644
--- a/modules/core/src/main/java/org/apache/ignite/IgniteCluster.java
+++ b/modules/core/src/main/java/org/apache/ignite/IgniteCluster.java
@@ -312,7 +312,7 @@ public interface IgniteCluster extends ClusterGroup, IgniteAsyncSupport {
      * Restarts nodes satisfying optional set of predicates.
      * <p>
      * <b>NOTE:</b> this command only works for grid nodes started with GridGain
-     * {@code ggstart.sh} or {@code ggstart.bat} scripts.
+     * {@code ignite.sh} or {@code ignite.bat} scripts.
      *
      * @throws IgniteCheckedException In case of error.
      */
@@ -322,7 +322,7 @@ public interface IgniteCluster extends ClusterGroup, IgniteAsyncSupport {
      * Restarts nodes defined by provided IDs.
      * <p>
      * <b>NOTE:</b> this command only works for grid nodes started with GridGain
-     * {@code ggstart.sh} or {@code ggstart.bat} scripts.
+     * {@code ignite.sh} or {@code ignite.bat} scripts.
      *
      * @param ids IDs defining nodes to restart.
      * @throws IgniteCheckedException In case of error.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/modules/core/src/main/java/org/apache/ignite/IgniteFs.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/IgniteFs.java b/modules/core/src/main/java/org/apache/ignite/IgniteFs.java
index ff7a9b6..7e672f1 100644
--- a/modules/core/src/main/java/org/apache/ignite/IgniteFs.java
+++ b/modules/core/src/main/java/org/apache/ignite/IgniteFs.java
@@ -39,8 +39,8 @@ import java.util.*;
  * This API is fully thread-safe and you can use it from several threads.
  * <h1 class="header">GGFS Configuration</h1>
  * The simplest way to run a GridGain node with configured file system is to pass
- * special configuration file included in GridGain distribution to {@code ggstart.sh} or
- * {@code ggstart.bat} scripts, like this: {@code ggstart.sh config/hadoop/default-config.xml}
+ * special configuration file included in GridGain distribution to {@code ignite.sh} or
+ * {@code ignite.bat} scripts, like this: {@code ignite.sh config/hadoop/default-config.xml}
  * <p>
  * {@code GGFS} can be started as a data node or as a client node. Data node is responsible for
  * caching data, while client node is responsible for basic file system operations and accessing

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/modules/core/src/main/java/org/apache/ignite/IgniteLogger.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/IgniteLogger.java b/modules/core/src/main/java/org/apache/ignite/IgniteLogger.java
index 0c7dd32..9245e6b 100644
--- a/modules/core/src/main/java/org/apache/ignite/IgniteLogger.java
+++ b/modules/core/src/main/java/org/apache/ignite/IgniteLogger.java
@@ -60,7 +60,7 @@ import org.jetbrains.annotations.*;
  * will operate in normal un-suppressed logging mode. Note that all output in "quiet" mode is
  * done through standard output (STDOUT).
  * <p>
- * Note that GridGain's standard startup scripts <tt>$IGNITE_HOME/bin/ggstart.{sh|bat}</tt> start
+ * Note that GridGain's standard startup scripts <tt>$IGNITE_HOME/bin/ignite.{sh|bat}</tt> start
  * by default in "quiet" mode. Both scripts accept {@code -v} arguments to turn off "quiet" mode.
  */
 @GridToStringExclude

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/modules/core/src/main/java/org/apache/ignite/IgniteSystemProperties.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/IgniteSystemProperties.java b/modules/core/src/main/java/org/apache/ignite/IgniteSystemProperties.java
index 0af1487..2e3b6aa 100644
--- a/modules/core/src/main/java/org/apache/ignite/IgniteSystemProperties.java
+++ b/modules/core/src/main/java/org/apache/ignite/IgniteSystemProperties.java
@@ -114,7 +114,7 @@ public final class IgniteSystemProperties {
      * of Ignite. In quiet mode, only warning and errors are printed into the log
      * additionally to a shortened version of standard output on the start.
      * <p>
-     * Note that if you use <tt>ggstart.{sh|bat}</tt> scripts to start Ignite they
+     * Note that if you use <tt>ignite.{sh|bat}</tt> scripts to start Ignite they
      * start by default in quiet mode. You can supply <tt>-v</tt> flag to override it.
      */
     public static final String IGNITE_QUIET = "IGNITE_QUIET";
@@ -135,7 +135,7 @@ public final class IgniteSystemProperties {
     /**
      * Name of the system property defining success file name. This file
      * is used with auto-restarting functionality when Ignite is started
-     * by supplied <tt>ggstart.{bat|sh}</tt> scripts.
+     * by supplied <tt>ignite.{bat|sh}</tt> scripts.
      */
     public static final String IGNITE_SUCCESS_FILE = "IGNITE_SUCCESS_FILE";
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/modules/core/src/main/java/org/apache/ignite/Ignition.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/Ignition.java b/modules/core/src/main/java/org/apache/ignite/Ignition.java
index ee878ca..478021c 100644
--- a/modules/core/src/main/java/org/apache/ignite/Ignition.java
+++ b/modules/core/src/main/java/org/apache/ignite/Ignition.java
@@ -85,7 +85,7 @@ public class Ignition {
      * for a JVM to restart itself from Java application and therefore we rely on
      * external tools to provide that capability.
      * <p>
-     * Note that standard <tt>ggstart.{sh|bat}</tt> scripts support restarting when
+     * Note that standard <tt>ignite.{sh|bat}</tt> scripts support restarting when
      * JVM process exits with this code.
      */
     public static final int RESTART_EXIT_CODE = 250;
@@ -226,7 +226,7 @@ public class Ignition {
      * should be responsible for stopping it.
      * <p>
      * Note also that restarting functionality only works with the tools that specifically
-     * support GridGain's protocol for restarting. Currently only standard <tt>ggstart.{sh|bat}</tt>
+     * support GridGain's protocol for restarting. Currently only standard <tt>ignite.{sh|bat}</tt>
      * scripts support restarting of JVM GridGain's process.
      *
      * @param cancel If {@code true} then all jobs currently executing on

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/modules/core/src/main/java/org/apache/ignite/client/router/GridRouterFactory.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/client/router/GridRouterFactory.java b/modules/core/src/main/java/org/apache/ignite/client/router/GridRouterFactory.java
index d8ea4f4..4d44c2f 100644
--- a/modules/core/src/main/java/org/apache/ignite/client/router/GridRouterFactory.java
+++ b/modules/core/src/main/java/org/apache/ignite/client/router/GridRouterFactory.java
@@ -34,7 +34,7 @@ import java.util.concurrent.*;
  * See {@link GridTcpRouter} for example on how to configure and start embedded router.
  * <h1 class="header">Standalone router startup</h1>
  * Alternatively you can run routers as a standalone processes by executing
- * {@code IGNITE_HOME/bin/ggrouter.sh} or {@code IGNITE_HOME/bin/ggrouter.bat}.
+ * {@code IGNITE_HOME/bin/igniterouter.sh} or {@code IGNITE_HOME/bin/igniterouter.bat}.
  * They both accept path to a configuration file as first command line argument.
  * See {@code IGNITE_HOME/config/router/default-router.xml} for configuration example.
  *

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/modules/core/src/main/java/org/apache/ignite/configuration/IgniteDeploymentMode.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/configuration/IgniteDeploymentMode.java b/modules/core/src/main/java/org/apache/ignite/configuration/IgniteDeploymentMode.java
index e14066c..ba410bc 100644
--- a/modules/core/src/main/java/org/apache/ignite/configuration/IgniteDeploymentMode.java
+++ b/modules/core/src/main/java/org/apache/ignite/configuration/IgniteDeploymentMode.java
@@ -61,7 +61,7 @@ import org.jetbrains.annotations.*;
  * <ol>
  *  <li>
  *      Simply startup stand-alone GridGain nodes by executing
- *      {@code IGNITE_HOME/ggstart.{sh|bat}} scripts.
+ *      {@code IGNITE_HOME/ignite.{sh|bat}} scripts.
  *  </li>
  *  <li>
  *      Now, all jobs executing locally or remotely can have a single instance of cache

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/modules/core/src/main/java/org/apache/ignite/internal/IgniteKernal.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/IgnitionEx.java b/modules/core/src/main/java/org/apache/ignite/internal/IgnitionEx.java
index 0f062dd..7dd9e73 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/IgnitionEx.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/IgnitionEx.java
@@ -336,7 +336,7 @@ public class IgnitionEx {
      * should be responsible for stopping it.
      * <p>
      * Note also that restarting functionality only works with the tools that specifically
-     * support GridGain's protocol for restarting. Currently only standard <tt>ggstart.{sh|bat}</tt>
+     * support GridGain's protocol for restarting. Currently only standard <tt>ignite.{sh|bat}</tt>
      * scripts support restarting of JVM GridGain's process.
      *
      * @param cancel If {@code true} then all jobs currently executing on

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/modules/core/src/main/java/org/apache/ignite/lifecycle/LifecycleBean.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/lifecycle/LifecycleBean.java b/modules/core/src/main/java/org/apache/ignite/lifecycle/LifecycleBean.java
index b6366b1..0095661 100644
--- a/modules/core/src/main/java/org/apache/ignite/lifecycle/LifecycleBean.java
+++ b/modules/core/src/main/java/org/apache/ignite/lifecycle/LifecycleBean.java
@@ -66,7 +66,7 @@ import org.apache.ignite.*;
  * If you need to tie your application logic into GridGain lifecycle,
  * you can configure lifecycle beans via standard grid configuration, add your
  * application library dependencies into {@code IGNITE_HOME/libs} folder, and
- * simply start {@code IGNITE_HOME/ggstart.{sh|bat}} scripts.
+ * simply start {@code IGNITE_HOME/ignite.{sh|bat}} scripts.
  * <p>
  * <h1 class="header">Configuration</h1>
  * Grid lifecycle beans can be configured programmatically as follows:

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/modules/core/src/main/java/org/apache/ignite/plugin/segmentation/GridSegmentationPolicy.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/plugin/segmentation/GridSegmentationPolicy.java b/modules/core/src/main/java/org/apache/ignite/plugin/segmentation/GridSegmentationPolicy.java
index e1d297c..bed865c 100644
--- a/modules/core/src/main/java/org/apache/ignite/plugin/segmentation/GridSegmentationPolicy.java
+++ b/modules/core/src/main/java/org/apache/ignite/plugin/segmentation/GridSegmentationPolicy.java
@@ -27,7 +27,7 @@ public enum GridSegmentationPolicy {
      * When segmentation policy is {@code RESTART_JVM}, all listeners will receive
      * {@link org.apache.ignite.events.IgniteEventType#EVT_NODE_SEGMENTED} event and then JVM will be restarted.
      * Note, that this will work <b>only</b> if GridGain is started with {@link org.apache.ignite.startup.cmdline.CommandLineStartup}
-     * via standard {@code ggstart.{sh|bat}} shell script.
+     * via standard {@code ignite.{sh|bat}} shell script.
      */
     RESTART_JVM,
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/modules/core/src/main/java/org/apache/ignite/startup/cmdline/CommandLineStartup.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/startup/cmdline/CommandLineStartup.java b/modules/core/src/main/java/org/apache/ignite/startup/cmdline/CommandLineStartup.java
index 7ee575a..52d5f20 100644
--- a/modules/core/src/main/java/org/apache/ignite/startup/cmdline/CommandLineStartup.java
+++ b/modules/core/src/main/java/org/apache/ignite/startup/cmdline/CommandLineStartup.java
@@ -47,7 +47,7 @@ import static org.apache.ignite.internal.GridProductImpl.*;
  * parameter which is Spring XML configuration file path. You can run this class from command
  * line without parameters to get help message.
  * <p>
- * Note that scripts {@code ${IGNITE_HOME}/bin/ggstart.{sh|bat}} shipped with GridGain use
+ * Note that scripts {@code ${IGNITE_HOME}/bin/ignite.{sh|bat}} shipped with GridGain use
  * this startup and you can use them as an example.
  */
 @SuppressWarnings({"CallToSystemExit"})
@@ -144,23 +144,23 @@ public final class CommandLineStartup {
         if (errMsg != null)
             X.error(errMsg);
 
-        String runner = System.getProperty(IGNITE_PROG_NAME, "ggstart.{sh|bat}");
+        String runner = System.getProperty(IGNITE_PROG_NAME, "ignite.{sh|bat}");
 
         int space = runner.indexOf(' ');
 
         runner = runner.substring(0, space == -1 ? runner.length() : space);
 
         if (showUsage) {
-            boolean ggstart = runner.contains("ggstart.");
+            boolean ignite = runner.contains("ignite.");
 
             X.error(
                 "Usage:",
-                "    " + runner + (ggstart ? " [?]|[path {-v}]|[-i]" : " [?]|[-v]"),
+                "    " + runner + (ignite ? " [?]|[path {-v}]|[-i]" : " [?]|[-v]"),
                 "    Where:",
                 "    ?, /help, -help - show this message.",
                 "    -v              - verbose mode (quiet by default).");
 
-            if (ggstart) {
+            if (ignite) {
                 X.error(
                     "    -i              - interactive mode (choose configuration file from list).",
                     "    path            - path to Spring XML configuration file.",

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/modules/core/src/main/java/org/apache/ignite/startup/cmdline/CommandLineTransformer.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/startup/cmdline/CommandLineTransformer.java b/modules/core/src/main/java/org/apache/ignite/startup/cmdline/CommandLineTransformer.java
index e9e3726..2a29095 100644
--- a/modules/core/src/main/java/org/apache/ignite/startup/cmdline/CommandLineTransformer.java
+++ b/modules/core/src/main/java/org/apache/ignite/startup/cmdline/CommandLineTransformer.java
@@ -26,12 +26,12 @@ import java.util.*;
  * Windows batch usage variables.
  * <p>
  * The idea behind the workaround is:<br>
- * 1. User runs ggstart.bat with some args.<br>
- * 2. ggstart.bat calls parseargs.bat with all that args.<br>
+ * 1. User runs ignite.bat with some args.<br>
+ * 2. ignite.bat calls parseargs.bat with all that args.<br>
  * 3. parsearg.bat runs this class with all that args.<br>
  * 4. This class transforms the args and prints them out.<br>
  * 5. parseargs.bat splits the output of this class and sets each variable it found.<br>
- * 6. ggstart.bat uses environment variables as if they were defined by a user.
+ * 6. ignite.bat uses environment variables as if they were defined by a user.
  * <p>
  *
  * @see <a href="http://jcommander.org/">JCommander command line parameters parsing library</a>

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/modules/core/src/test/bin/start-nodes-custom.bat
----------------------------------------------------------------------
diff --git a/modules/core/src/test/bin/start-nodes-custom.bat b/modules/core/src/test/bin/start-nodes-custom.bat
index ad4829b..51fbce0 100644
--- a/modules/core/src/test/bin/start-nodes-custom.bat
+++ b/modules/core/src/test/bin/start-nodes-custom.bat
@@ -19,4 +19,4 @@ if %SCRIPT_DIR:~-1,1% == \ set SCRIPT_DIR=%SCRIPT_DIR:~0,-1%
 
 :: -np option is mandatory, if it is not provided then we will wait for a user input,
 :: as a result ggservice windows service hangs forever
-call "%SCRIPT_DIR%\..\..\..\..\..\bin\ggstart.bat" -v -np modules\core\src\test\config\spring-start-nodes-attr.xml
+call "%SCRIPT_DIR%\..\..\..\..\..\bin\ignite.bat" -v -np modules\core\src\test\config\spring-start-nodes-attr.xml

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/modules/core/src/test/bin/start-nodes-custom.sh
----------------------------------------------------------------------
diff --git a/modules/core/src/test/bin/start-nodes-custom.sh b/modules/core/src/test/bin/start-nodes-custom.sh
index 6845b79..75dba94 100755
--- a/modules/core/src/test/bin/start-nodes-custom.sh
+++ b/modules/core/src/test/bin/start-nodes-custom.sh
@@ -18,4 +18,4 @@ SCRIPT_DIR=$(cd $(dirname "$0"); pwd)
 
 BIN_DIR="${SCRIPT_DIR}"/../../../../..
 
-"${BIN_DIR}"/bin/ggstart.sh -v modules/core/src/test/config/spring-start-nodes-attr.xml
+"${BIN_DIR}"/bin/ignite.sh -v modules/core/src/test/config/spring-start-nodes-attr.xml
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/IgniteKernal.java b/modules/core/src/main/java/org/apache/ignite/internal/IgniteKernal.java
index 4bd44d6..dc9d81d 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/IgniteKernal.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/IgniteKernal.java
@@ -1678,7 +1678,7 @@ public class IgniteKernal extends ClusterGroupAdapter implements IgniteEx, Ignit
         if (ctx.isEnterprise())
             U.quietAndInfo(log, "To start GUI Management & Monitoring run ggvisorui.{sh|bat}");
         else
-            U.quietAndInfo(log, "To start Console Management & Monitoring run ggvisorcmd.{sh|bat}");
+            U.quietAndInfo(log, "To start Console Management & Monitoring run ignitevisorcmd.{sh|bat}");
     }
 
     /**
@@ -1718,7 +1718,7 @@ public class IgniteKernal extends ClusterGroupAdapter implements IgniteEx, Ignit
                     U.quiet(false, "  ^-- Logging to file '" +  fileName + '\'');
 
                 U.quiet(false,
-                    "  ^-- To see **FULL** console log here add -DIGNITE_QUIET=false or \"-v\" to ggstart.{sh|bat}",
+                    "  ^-- To see **FULL** console log here add -DIGNITE_QUIET=false or \"-v\" to ignite.{sh|bat}",
                     "");
             }
 
@@ -2226,7 +2226,7 @@ public class IgniteKernal extends ClusterGroupAdapter implements IgniteEx, Ignit
 
     /**
      * Whether or not node restart is enabled. Node restart us supported when this node was started
      * with {@code bin/ggstart.{sh|bat}} script using {@code -r} argument. Node can be
      * programmatically restarted using {@link org.apache.ignite.Ignition#restart(boolean)}} method.
      *
      * @return {@code True} if restart mode is enabled, {@code false} otherwise.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/7e8ea4f1/modules/core/src/main/java/org/apache/ignite/internal/IgnitionEx.java
----------------------------------------------------------------------
@@ -2226,7 +2226,7 @@ public class IgniteKernal extends ClusterGroupAdapter implements IgniteEx, Ignit
     /**
      * Whether or not node restart is enabled. Node restart us supported when this node was started
-     * with {@code bin/ggstart.{sh|bat}} script using {@code -r} argument. Node can be
+     * with {@code bin/ignite.{sh|bat}} script using {@code -r} argument. Node can be
      * programmatically restarted using {@link org.apache.ignite.Ignition#restart(boolean)}} method.
      *